@@ -19,7 +19,7 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-     $Id: http.cpp,v 1.23 2003/03/05 08:12:40 robert Exp $
+     $Id: http.cpp,v 1.24 2004/03/05 21:34:29 robert Exp $
 
 ----------------------------------------------------------------------------*/
 #include <stdio.h> 
@@ -90,7 +90,7 @@ MBHttp::MBHttp(void)
 MBHttp::~MBHttp(void)
 {
     if (m_buffer)
-       delete m_buffer;
+       delete [] m_buffer;
 
     if (m_file)
         fclose(m_file);
@@ -113,7 +113,7 @@ Error MBHttp::DownloadToString(const string &url,
 
     if (m_buffer)
     {
-       delete m_buffer;
+       delete [] m_buffer;
        m_buffer = NULL;
     }
 
@@ -152,7 +152,7 @@ int MBHttp::WriteToBuffer(unsigned char *buffer, unsigned int size)
         pTemp = new unsigned char[m_bufferSize];
 
         memcpy(pTemp, m_buffer, m_bytesInBuffer);
-        delete m_buffer;
+        delete [] m_buffer;
         m_buffer = pTemp;
     }
 
