@@ -18,7 +18,7 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-   $Id: signature.cpp,v 1.32 2003/04/01 02:31:35 robert Exp $
+   $Id: signature.cpp,v 1.35 2004/03/09 00:08:14 robert Exp $
 ----------------------------------------------------------------------------*/
 
 #include "trm.h"
@@ -45,6 +45,9 @@ const int iNumSamplesNeeded = 288000;
    typedef long long llong;
 #endif
 
+char silenceTRM[] = { 0x7d, 0x15, 0x4f, 0x52, 0xb5, 0x36, 0x4f, 0xae, 
+                      0xb5, 0x8b, 0x06, 0x66, 0x82, 0x6c, 0x2b, 0xac, 0x00 };
+
 TRM::TRM(void)
 {
     m_downmixBuffer = NULL;
@@ -57,6 +60,14 @@ TRM::TRM(void)
 
 TRM::~TRM(void)
 {
+    if (m_downmixBuffer) {
+	delete [] m_downmixBuffer;
+	m_downmixBuffer = NULL;
+    }
+    if (m_storeBuffer) {
+        delete [] m_storeBuffer;
+        m_storeBuffer = NULL;
+    }
 }
 
 bool TRM::SetProxy(const string &proxyAddr, short proxyPort)
@@ -67,11 +78,16 @@ bool TRM::SetProxy(const string &proxyAddr, short proxyPort)
     return true;
 }
 
-void TRM::SetPCMDataInfo(int samplesPerSecond, int numChannels,
+bool TRM::SetPCMDataInfo(int samplesPerSecond, int numChannels,
                          int bitsPerSample)
 {
     m_samples_per_second = samplesPerSecond;
+
+    if (numChannels != 1 && numChannels != 2) 
+      return false;
     m_number_of_channels = numChannels;
+    if (bitsPerSample != 8 && bitsPerSample != 16)
+      return false;
     m_bits_per_sample = bitsPerSample;
 
     if (m_downmixBuffer) {
@@ -95,6 +111,7 @@ void TRM::SetPCMDataInfo(int samplesPerSecond, int numChannels,
 
     m_song_samples = 0;
     m_song_seconds = -1;
+    return true;
 }
 
 void TRM::SetSongLength(long seconds)
@@ -426,12 +443,7 @@ int TRM::FinalizeSignature(string &strGUID, string &collID)
 {
     if (m_numBytesWritten < 2)
     {
-        SigXDR conv;
-        char   buffer[64];
-
-        memset(buffer, 0xFF, 64);
-        strGUID = conv.ToStrGUID(buffer, 64);
-
+        strGUID = string(silenceTRM);
         return 0;
     }
 
